function out = WideMean(in, frame)
%A function that moves along the points of the data and attempts to smooth
%them by computing a weighted average of the values at the point and
%surrounding it.
%
%The columns of the data are the points, whilst the rows are the
%replicates.
%
%Inputs:
%   * in - the data in question, a 2-d array of values
%   * frame - the weights for the averaging, the center position (the frame
%   has to have an odd length) is the point in question

%check if the frame is of an odd length
if mod(size(frame,2),2) == 0
    fprintf('The frame needs to be of an odd length. Terminating.\n');
    return
end

%check for size compatibility
if size(frame,1) ~= size(in,1)
    fprintf('The data and the frame need the same number of rows. Terminating.\n');
    return
end

%otherwise, proceed to the proper approximation
out = zeros(1,size(in,2));
width = (size(frame,2)-1)/2;
%buffer input with zeros
in2 = [zeros(size(in,1),width) in zeros(size(in,1),width)];
framecheck = [zeros(size(in,1),width) ones(size(in)) zeros(size(in,1),width)];

%proper averaging
for i=1:size(in,2)
    out(i) = sum(sum(in2(1:size(in,1),i:i+2*width).*frame))/...
        sum(sum(framecheck(1:size(in,1),i:i+2*width).*frame));
end